@@ -5,7 +5,7 @@
 #include <qcheckbox.h>
 #include <klocale.h>
 
-Finder::Finder(QWidget *parent) : KDialogBase(parent, 0, false, i18n("Find"), Close | User1, User1, false, i18n("&Find"))
+Finder::Finder(QWidget *parent) : KDialogBase(parent, 0, false, i18n("Find"), Close | User1, User1, false, KGuiItem(i18n("&Find"),"find"))
 {
 	QWidget *mainWidget = new QWidget(this);
 	mainWidget->setMinimumWidth(320);
