@@ -20,7 +20,7 @@
 class VISQueue {
 
   int elements;
-  std::vector< std::vector<float>* > visArrayQueue; 
+  std::vector<float> **visArrayQueue; 
 
  public:
   VISQueue(int elements);
