@@ -18,12 +18,9 @@
 */
 
 #ifndef _VIDEOCREATOR_H_
-#define _VIDEOCREATOR_H_ "$Id: videocreator.h,v 1.1 2002/06/12 22:48:23 macmullen Exp $"
+#define _VIDEOCREATOR_H_ "$Id: videocreator.h 208422 2003-02-21 21:22:09Z snel $"
 
 #include <kio/thumbcreator.h>
-#include <kartsserver.h>
-#include <kplayobjectfactory.h>
-#include <kartsdispatcher.h>
 
 class VideoCreator : public QObject, public ThumbCreator
 {
@@ -34,27 +31,10 @@ public:
     virtual bool create(const QString &path, int width, int height, QImage &img);
     virtual Flags flags() const;
 
-protected:
-    virtual void timerEvent(QTimerEvent *);
-
-private slots:
-    void slotCompleted();
-
 private:
-    void pause (int ms);
-    double imageVariance (QImage&);
-    void mutePlayObject (Arts::PlayObject object);
-    
-    static const int maximumAttempts = 1;
-
     QPixmap m_sprocketSmall;
     QPixmap m_sprocketMedium;
     QPixmap m_sprocketLarge;
-    KPlayObject* m_playobj;
-    KArtsServer m_server;
-    KArtsDispatcher m_dispatcher;
-    
-    bool m_completed;
 };
 
 #endif
